@@ -73,6 +73,7 @@ Module::Install::TestBase - Module::Install Support for YAML::Tests
 
 =head1 SYNOPSIS
 
+    # Example Makefile.PL
     use inc::Module::Install;
 
     name            'YAML::Foo';
@@ -84,27 +85,22 @@ Module::Install::TestBase - Module::Install Support for YAML::Tests
 
 =head1 DESCRIPTION
 
-This module defines a number of implementation independent tests that can be
-used to test various YAML implementations.
-
-There are two ways to use this module. If you are the author of a Perl YAML
-implementation, you can add the line:
+By adding the single line:
 
     use_yaml_tests;
 
-to your C<Makefile.PL> as shown in the synopsis. This will copy the tests from
-YAML::Tests into your module's test area. You must also define a file called
-C<t/yaml_tests.yaml> as described below.
+to your C<Module::Install> based C<Makefile.PL>, when you then run
+the command:
 
-If you are Just Another Perl Hacker, YAML-Tests installs a command line tool
-called C<yt> to run the YAML Tests against a specific module. Like this:
+    perl Makefile.PL
 
-    > yt YAML::Syck
+the YAML::Tests test files will be copied into your module's C<t/>
+directory.
 
 =head1 CONFIGURATION
 
-If you are YAML::Tests in your own YAML module, create a file called
-C<t/yaml_tests.yaml>. Here is an example:
+If you are using C<YAML::Tests> in your own YAML module, create a
+file called C<t/yaml_tests.yaml>. Here is an example:
 
     # YAML::Tests Config File
     
